summaryrefslogtreecommitdiffstats
path: root/tdecore/kinstance.h
diff options
context:
space:
mode:
Diffstat (limited to 'tdecore/kinstance.h')
-rw-r--r--tdecore/kinstance.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/tdecore/kinstance.h b/tdecore/kinstance.h
index 775fe3bdf..8178fe9c5 100644
--- a/tdecore/kinstance.h
+++ b/tdecore/kinstance.h
@@ -20,7 +20,7 @@
class KStandardDirs;
class TDEAboutData;
-class KConfig;
+class TDEConfig;
class KIconLoader;
class KCharsets;
class TQFont;
@@ -86,13 +86,13 @@ class TDECORE_EXPORT TDEInstance
/**
* Returns the general config object ("appnamerc").
* @return the KConfig object for the instance.
*/
- KConfig *config() const;
+ TDEConfig *config() const;
/**
* Returns the general config object ("appnamerc").
* @return the KConfig object for the instance.
*/
KSharedConfig *sharedConfig() const;
@@ -165,7 +165,7 @@ protected:
private:
mutable KStandardDirs *_dirs;
- mutable KConfig *_config;
+ mutable TDEConfig *_config;
mutable KIconLoader *_iconLoader;
mutable TDEHardwareDevices *_hardwaredevices;
@@ -86,13 +86,13 @@ class TDECORE_EXPORT TDEInstance
/**
* Returns the general config object ("appnamerc").
- * @return the KConfig object for the instance.
+ * @return the TDEConfig object for the instance.
*/
@@ -86,13 +86,13 @@ class TDECORE_EXPORT TDEInstance
/**
* Returns the general config object ("appnamerc").
- * @return the KConfig object for the instance.
+ * @return the TDEConfig object for the instance.
*/
KSharedConfig *sharedConfig() const;